@@ -44,6 +44,15 @@ func Test_getShowText(t *testing.T) {
 			showType: SHOW_TITLE,
 			expected: "<Cats and Dogs>",
 		},
+		{
+			name: "with source-title",
+			feedItem: &FeedItem{
+				sourceTitle: "WTF",
+				item:        &gofeed.Item{Title: "<Cats and Dogs>"},
+			},
+			showType: SHOW_TITLE,
+			expected: "[WTF] <Cats and Dogs>",
+		},
 		{
 			name: "with link",
 			feedItem: &FeedItem{
