@@ -36,7 +36,7 @@ type Widget struct {
 	err      error
 }
 
-func NewWidget(tviewApp *tview.Application, pages *tview.Pages, settings *Settings) *Widget {
+func NewWidget(tviewApp *tview.Application, redrawChan chan bool, pages *tview.Pages, settings *Settings) *Widget {
 	var widget Widget
 
 	leagueId, err := getLeague(settings.league)
@@ -51,7 +51,7 @@ func NewWidget(tviewApp *tview.Application, pages *tview.Pages, settings *Settin
 	}
 
 	widget = Widget{
-		TextWidget: view.NewTextWidget(tviewApp, pages, settings.Common),
+		TextWidget: view.NewTextWidget(tviewApp, redrawChan, pages, settings.Common),
 		Client:     NewClient(settings.apiKey),
 		League:     leagueId,
 		settings:   settings,
